==> rapid_widgets_library-0.2.58.tar.gz: lib/payment-web.dart <==
import 'package:flutter/material.dart';
// import 'package:fluttertoast/fluttertoast.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:razorpay_flutter/razorpay_flutter.dart';
import 'dart:html';
import 'dart:ui' as ui;


class PaymentWeb extends StatefulWidget {
  final PaymentGatewayParams paymentGatewayParams;
  PaymentWeb({this.paymentGatewayParams});

  @override
  _PaymentWebState createState() => _PaymentWebState();
}

class _PaymentWebState extends State<PaymentWeb> {
  Razorpay _razorpay;
  @override
  void initState() {
    // TODO: implement initState
    _razorpay =Razorpay();
    _razorpay.on(Razorpay.EVENT_PAYMENT_SUCCESS,handlePaymentSuccess);
    _razorpay.on(Razorpay.EVENT_PAYMENT_ERROR,handlePaymentError);
    _razorpay.on(Razorpay.EVENT_EXTERNAL_WALLET, handleExternalWallet);
    super.initState();
  }
  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _razorpay.clear();
  }
  void handlePaymentSuccess(){
    // Fluttertoast.showToast(msg: "SUCCESS"+response.paymentId!=null?response.paymentId:'0',
    //     toastLength: Toast.LENGTH_LONG);
    return (widget.paymentGatewayParams.onSuccess != null) ? widget.paymentGatewayParams.onSuccess() : null;

  }
  void handlePaymentError(){
    // Fluttertoast.showToast(
    //     msg: "ERROR: " + response.code.toString() + " - " + response.message.toString(),
    //     toastLength: Toast.LENGTH_LONG);
    return (widget.paymentGatewayParams.onFailure != null) ? widget.paymentGatewayParams.onFailure() : null;

  }
  void handleExternalWallet(ExternalWalletResponse response){
    // Fluttertoast.showToast(msg: "Wallet:"+response.walletName.toString(),toastLength: Toast.LENGTH_LONG);
  }

  void openCheckout()async{
    Map<String, dynamic> options ={
      'key': widget.paymentGatewayParams.key!='null'?widget.paymentGatewayParams.key:'rzp_test_aClrm9BsmfBxt6',
      'amount': widget.paymentGatewayParams.amount!=null?widget.paymentGatewayParams.amount:'1000',
      'name': widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Low Code Platform',
      'description':widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Payment-test',
      'prefill':{
        'contact':widget.paymentGatewayParams.contactNumber!='null'?widget.paymentGatewayParams.contactNumber:'1234567890',
        'email':widget.paymentGatewayParams.contactEmail!='null'?widget.paymentGatewayParams.contactEmail:'user@pwc.com'
      },
      'external':{
        'wallets':['paytm']
      }
    };
    try{
      // _razorpay.open(options);
      dynamic response = await Navigator.push(
          context,
          MaterialPageRoute(builder: (context) => RazorPayWeb(options)));

      if(response == 'SUCCESS')
        handlePaymentSuccess();
      else
        handlePaymentError();

    }
    catch(e){
      print(e.toString());
    }
  }
  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: widget.paymentGatewayParams.textAlign,
      child:  Padding(
        padding:  EdgeInsets.only(
          left: widget.paymentGatewayParams.paddingLeft!=null?widget.paymentGatewayParams.paddingLeft:0.0,
          right:  widget.paymentGatewayParams.paddingRight!=null?widget.paymentGatewayParams.paddingRight:0.0,
          top:  widget.paymentGatewayParams.paddingTop!=null?widget.paymentGatewayParams.paddingTop:0.0,
          bottom:  widget.paymentGatewayParams.paddingBottom!=null?widget.paymentGatewayParams.paddingBottom:0.0,
        ),
        child: widget.paymentGatewayParams.iconData!=null?ElevatedButton.icon(
          onPressed: () {
            openCheckout();
          },
          label: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          icon: Icon(widget.paymentGatewayParams.iconData,size: widget.paymentGatewayParams.iconSize??0,color: widget.paymentGatewayParams.iconColor??Colors.white,),
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ):ElevatedButton(
          child: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          onPressed: () {
            openCheckout();
          },
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ),
      ),
    );
  }
}



class RazorPayWeb extends StatelessWidget {
  Map<String, dynamic> options;
  RazorPayWeb(this.options);

  @override
  Widget build(BuildContext context) {
    ui.platformViewRegistry.registerViewFactory("rzp-html",(int viewId) {
      IFrameElement element=IFrameElement();

      window.onMessage.forEach((element) {
        print('Event Received in callback: ${element.data}');
        if(element.data=='MODAL_CLOSED'){
          // Fluttertoast.showToast(
          //     msg: "Failed",
          //     toastLength: Toast.LENGTH_LONG
          // );
          Navigator.of(context).pop("FAILED");
        }else if(element.data['event'] == 'SUCCESS'){
          Navigator.of(context).pop("SUCCESS");
          // Fluttertoast.showToast(
          //     msg: "Success! Your payment id ${element.data['data']??0}",
          //     toastLength: Toast.LENGTH_LONG
          // );
          print('PAYMENT SUCCESSFULL!!!!!!! -- Payment ID' + element.data['data']);
        }
      });

      element.requestFullscreen();
      element.src='assets/payment.html?';
      //element.src='https://razorpay-checkout.azurewebsites.net/checkout.php?';
      int i = 0;
      int length = options.length;
      options.forEach((key, value){
        if(key == "prefill"){
          value.forEach((k, v){
            element.src += "$k=$v";
            if(length-1 != i){
              element.src += "&";
            }
          });
        }else{
          element.src += "$key=$value";
          if (length - 1 != i) {
            element.src += "&";
          }
        }
        i++;
      });
      print("element.src ==== ${element.src}");
      element.style.border = 'none';
      return element;
    });
    return Scaffold(
        body: Builder(builder: (BuildContext context) {
          return const HtmlElementView(viewType: 'rzp-html');
        }));
  }

}

// ignore: camel_case_types
class platformViewRegistry {
  static registerViewFactory(String viewId, dynamic cb) {
    ui.platformViewRegistry.registerViewFactory(viewId, cb);
  }
}

==> rapid_widgets_library-0.2.59.tar.gz: lib/payment-web.dart <==
import 'package:flutter/material.dart';
// import 'package:fluttertoast/fluttertoast.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:razorpay_flutter/razorpay_flutter.dart';
import 'dart:html';
import 'dart:ui' as ui;
import 'package:rapid_widgets_library/payment_service.dart';


class PaymentWeb extends StatefulWidget {
  final PaymentGatewayParams paymentGatewayParams;
  PaymentWeb({this.paymentGatewayParams});

  @override
  _PaymentWebState createState() => _PaymentWebState();
}

class _PaymentWebState extends State<PaymentWeb> {

  void openCheckout() async{
    PaymentService().startPayment(
      widget.paymentGatewayParams.key!='null'?widget.paymentGatewayParams.key:'rzp_test_aClrm9BsmfBxt6',
      int.parse(widget.paymentGatewayParams.amount!=null?widget.paymentGatewayParams.amount:'1000'),
      widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Low Code Platform',
        widget.paymentGatewayParams.contactEmail!='null'?widget.paymentGatewayParams.contactEmail:'user@pwc.com',
          () => (widget.paymentGatewayParams.onSuccess != null) ? widget.paymentGatewayParams.onSuccess() : null,
          () => (widget.paymentGatewayParams.onFailure != null) ? widget.paymentGatewayParams.onFailure() : null,
    );
  }
  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: widget.paymentGatewayParams.textAlign,
      child:  Padding(
        padding:  EdgeInsets.only(
          left: widget.paymentGatewayParams.paddingLeft!=null?widget.paymentGatewayParams.paddingLeft:0.0,
          right:  widget.paymentGatewayParams.paddingRight!=null?widget.paymentGatewayParams.paddingRight:0.0,
          top:  widget.paymentGatewayParams.paddingTop!=null?widget.paymentGatewayParams.paddingTop:0.0,
          bottom:  widget.paymentGatewayParams.paddingBottom!=null?widget.paymentGatewayParams.paddingBottom:0.0,
        ),
        child: widget.paymentGatewayParams.iconData!=null?ElevatedButton.icon(
          onPressed: () {
            openCheckout();
          },
          label: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          icon: Icon(widget.paymentGatewayParams.iconData,size: widget.paymentGatewayParams.iconSize??0,color: widget.paymentGatewayParams.iconColor??Colors.white,),
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ):ElevatedButton(
          child: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          onPressed: () {
            openCheckout();
          },
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ),
      ),
    );
  }
}
